==> piwigo-2.5.1.zip: piwigo/language/fi_FI/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['%s ago'] = '%s sitten';
$lang['... or '] = '... tai';
$lang['%d years'] = '%d vuodet';
$lang['%d year'] = '%d vuosi';
$lang['%d week'] = '%d viikko';
$lang['%d weeks'] = '%d viikot';
$lang['%d seconds'] = '%d sekunnit';
$lang['%d users deleted'] = '%d käyttäjät poistettu';
$lang['%d users'] = '%d käyttäjät';
$lang['%d user'] = '%d käyttäjä';
$lang['%d second'] = '%d sekunti';
$lang['%d photo was deleted'] = '%d kuva poistettu';
$lang['%d photos uploaded'] = '%d kuvat ladattu';
$lang['%d photos were deleted'] = '%d kuvat poistettu';
$lang['%d month'] = '%d kuukausi';
$lang['%d months'] = '%d kuukausia';
$lang['%d minute'] = '%d minuutti';
$lang['%d minutes'] = '%d minuutteja';
$lang['%d groups'] = '%d ryhmät';
$lang['%d days'] = '%d päivät';
$lang['%d group'] = '%d ryhmä';
$lang['%d day'] = '%d päivä';
$lang['%d albums moved'] = '%d albumia siirretty';
$lang['%d guests'] = '%d vierasta';
$lang['%d guest'] = '%d vieras';
$lang['Description'] = 'Kuvaus';
$lang['Database'] = 'Tietokanta';
$lang['Check for updates'] = 'Tarkista päivitykset';
$lang['Can\'t create temporary file.'] = 'Väliaikaistiedostoa ei voida luoda.';
$lang['Week starts on'] = 'Viikon ensimmäinen päivä on';
$lang['Watermark'] = 'Vesileima';
$lang['Version'] = 'Versio';
$lang['Tools'] = 'Työkalut';
$lang['Summary'] = 'Yhteenveto';
$lang['Send'] = 'Lähetä';
$lang['See you soon.'] = 'Näkemiin.';
$lang['Path'] = 'Polku';
$lang['Panorama'] = 'Panorama';
$lang['Operating system'] = 'Käyttöjärjestelmä';
$lang['Opacity'] = 'Läpinäkyvyys';
$lang['No results'] = 'Ei tuloksia';
$lang['Move'] = 'Siirrä';
$lang['File'] = 'Tiedosto';
$lang['ERROR'] = 'VIRHE';
$lang['Drop into album'] = 'Valitse albumi';
$lang['Documentation'] = 'Dokumentaatio';
$lang['Directory'] = 'Hakemisto';
$lang['Crop'] = 'Rajaa';
$lang['Cancel'] = 'Peruuta';
$lang['Allow rating'] = 'Salli arvosanat';
$lang['Album name'] = 'Albumin nimi';
$lang['Add a user'] = 'Lisää käyttäjä';
$lang['Add'] = 'Lisää';
$lang['A new version of Piwigo is available.'] = 'Uusi versio Piwigosta on saatavilla.';
$lang['ACCESS_0'] = 'Vapaa pääsy';
$lang['%d user deleted'] = '%d käyttäjä poistettu';
$lang['%d hour'] = '%d tunti';
$lang['%d hours'] = '%d tuntia';
$lang['%d member'] = '%d jäsen';
$lang['%d members'] = '%d jäsentä';
$lang['Allow user customization'] = 'Salli kustomointi käyttäjille';
$lang['Allow users to edit their own comments'] = 'Salli käyttäjien muokata kommenttejaan';
$lang['Allow users to delete their own comments'] = 'Salli käyttäjien poistaa kommenttejaan';
$lang['Allow user registration'] = 'Salli käyttäjien rekisteröityminen';
$lang['All themes are up to date.'] = 'Kaikki teemat ovat ajan tasalla.';
$lang['%d parameters were updated.'] = '%d parametriä päivitetty.';
$lang['%d parameter was updated.'] = '%d parametri päivitetty.';
$lang['%d mails were sent.'] = '%d sähköpostiviestiä lähetetty.';
$lang['%d mail was sent.'] = '%d sähköpostiviesti lähetetty.';
$lang['%d mail was not sent.'] = '%d sähköpostiviesti lähettämättä.';
$lang['%d mails were not sent.'] = '%d sähköpostiviestiä lähettämättä.';
$lang['%d albums including'] = '%d albumia sisältäen';
$lang['%d album including'] = '%d albumi sisältäen';
$lang['Choose an action'] = 'Valitse toiminto';
$lang['%d user was updated.'] = '%d käyttäjä päivitetty.';
$lang['%d users were not updated.'] = '%d käyttäjää ei päivitetty.';
$lang['%d users were updated.'] = '%d käyttäjää päivitetty.';
$lang['%d album moved'] = '%d albumi siirretty';
$lang['Level 0'] = '---';
$lang['Level 4'] = 'Perhe';
$lang['Level 2'] = 'Kaverit';
$lang['Level 1'] = 'Kontaktit';
$lang['Main Page'] = 'Pääsivu';
$lang['IP'] = 'IP';
$lang['I decide to update anyway'] = 'Haluan päivittää silti';
$lang['Form'] = 'Lomake';
$lang['Groups'] = 'Ryhmät';
$lang['Groups and users'] = 'Ryhmät ja käyttäjät';
$lang['Guest Settings'] = 'Vieraiden asetukset';
$lang['Guest cannot be deleted'] = 'Vierasta ei voi poistaa';
$lang['Guests'] = 'Vieraat';
$lang['Height'] = 'Korkeus';
$lang['Hello'] = 'Hei';
$lang['Hello,'] = 'Hei,';
$lang['Group name'] = 'Ryhmän nimi';
$lang['Group management'] = 'Ryhmien hallinta';
$lang['Group'] = 'Ryhmä';
$lang['Go to'] = 'Siirry';
$lang['General statistics'] = 'Yleiset tilastot';
$lang['Deleted on'] = 'Poistettu';
$lang['Correction applied with success'] = 'Korjaus onnistuneesti lisätty';
$lang['Correction'] = 'Korjaus';
$lang['Check integrity'] = 'Eheyden tarkistus';
$lang['Check all'] = 'Valitse kaikki';
$lang['%s has been successfully updated.'] = '%s päivitettiin onnistuneesti.';
$lang['%d waiting for validation'] = '%d odottaa hyväksyntää';
$lang['%d user was not updated.'] = '%d käyttäjää ei päivitetty';
$lang[' and %d virtuals'] = 'ja %d virtuaalista';
$lang[' and %d virtual'] = 'ja %d virtuaalinen';
$lang['Rename'] = 'Nimeä uudelleen';
$lang['Please wait...'] = 'Odota, ole hyvä...';
$lang['Piwigo version'] = 'Piwigon versio';
$lang['Overall'] = 'Yleiskatsaus';
$lang['Minimum height'] = 'Vähimmäiskorkeus';
$lang['Locked'] = 'Lukittu';
$lang['Lock gallery'] = 'Lukitse galleria';
$lang['Lock albums'] = 'Lukitse albumit';
$lang['Installed Themes'] = 'Asennetut teemat';
$lang['Installed Languages'] = 'Asennetut kielet';
$lang['Help Me'] = 'Apua';
$lang['Duplicates'] = 'Kaksoiskappaleet';
$lang['Duplicate'] = 'Kahdenna';
$lang['Delete selected users'] = 'Poista valitut käyttäjät';
$lang['Delete this language'] = 'Poista tämä kieli';
$lang['Delete Representant'] = 'Poista albumin esikatselukuva';
$lang['%d anomalies have been detected corrected.'] = '%d epäkohtaa löydetty ja korjattu.';
$lang['%d anomalies have been detected.'] = '%d epäkohtaa havaittu.';
$lang['%d anomalies have been ignored.'] = '%d epäkohtaa ohitettu.';
$lang['%d anomalies have not been corrected.'] = '%d epäkohtaa ei ole korjattu.';
$lang['%d anomaly has been corrected.'] = '%d epäkohtaa korjattiin.';
$lang['%d anomaly has been detected.'] = '%d epäkohtaa havaittiin.';
$lang['%d anomaly has been ignored.'] = '%d epäkohtaa ohitettiin.';
$lang['%d anomaly has not been corrected.'] = '%d ei olla korjattu.';
$lang['%d association'] = '%d assosiaatiota';
$lang['%d associations'] = '%d assosiaatiota';
$lang['%d line filtered'] = '%d rivi rajattu';
$lang['%d lines filtered'] = '%d riviä rajattu';
$lang['%d of %d photos selected'] = '%d/%d kuvaa valittu';
$lang['%d physical'] = '%d fyysistä';
$lang['%d physicals'] = '%d fyysistä';
$lang['%d tag'] = '%d tunniste';
$lang['%d tags'] = '%d tunnistetta';
$lang['%d user comment rejected'] = '%d kommentti hylätty';
$lang['%d user comment validated'] = '%d kommentti hyväksytty';
$lang['%d user comments rejected'] = '%d kommenttia hylätty';
?>

==> piwigo-2.5.3.zip: piwigo/language/fi_FI/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['%s ago'] = '%s sitten';
$lang['... or '] = '... tai';
$lang['%d years'] = '%d vuodet';
$lang['%d year'] = '%d vuosi';
$lang['%d week'] = '%d viikko';
$lang['%d weeks'] = '%d viikot';
$lang['%d seconds'] = '%d sekunnit';
$lang['%d users deleted'] = '%d käyttäjät poistettu';
$lang['%d users'] = '%d käyttäjät';
$lang['%d user'] = '%d käyttäjä';
$lang['%d second'] = '%d sekunti';
$lang['%d photo was deleted'] = '%d kuva poistettu';
$lang['%d photos uploaded'] = '%d kuvat ladattu';
$lang['%d photos were deleted'] = '%d kuvat poistettu';
$lang['%d month'] = '%d kuukausi';
$lang['%d months'] = '%d kuukausia';
$lang['%d minute'] = '%d minuutti';
$lang['%d minutes'] = '%d minuutteja';
$lang['%d groups'] = '%d ryhmät';
$lang['%d days'] = '%d päivät';
$lang['%d group'] = '%d ryhmä';
$lang['%d day'] = '%d päivä';
$lang['%d albums moved'] = '%d albumia siirretty';
$lang['%d guests'] = '%d vierasta';
$lang['%d guest'] = '%d vieras';
$lang['Description'] = 'Kuvaus';
$lang['Database'] = 'Tietokanta';
$lang['Check for updates'] = 'Tarkista päivitykset';
$lang['Can\'t create temporary file.'] = 'Väliaikaistiedostoa ei voida luoda.';
$lang['Week starts on'] = 'Viikon ensimmäinen päivä on';
$lang['Watermark'] = 'Vesileima';
$lang['Version'] = 'Versio';
$lang['Tools'] = 'Työkalut';
$lang['Summary'] = 'Yhteenveto';
$lang['Send'] = 'Lähetä';
$lang['See you soon.'] = 'Näkemiin.';
$lang['Path'] = 'Polku';
$lang['Panorama'] = 'Panorama';
$lang['Operating system'] = 'Käyttöjärjestelmä';
$lang['Opacity'] = 'Läpinäkyvyys';
$lang['No results'] = 'Ei tuloksia';
$lang['Move'] = 'Siirrä';
$lang['File'] = 'Tiedosto';
$lang['ERROR'] = 'VIRHE';
$lang['Drop into album'] = 'Valitse albumi';
$lang['Documentation'] = 'Dokumentaatio';
$lang['Directory'] = 'Hakemisto';
$lang['Crop'] = 'Rajaa';
$lang['Cancel'] = 'Peruuta';
$lang['Allow rating'] = 'Salli arvosanat';
$lang['Album name'] = 'Albumin nimi';
$lang['Add a user'] = 'Lisää käyttäjä';
$lang['Add'] = 'Lisää';
$lang['A new version of Piwigo is available.'] = 'Uusi versio Piwigosta on saatavilla.';
$lang['ACCESS_0'] = 'Vapaa pääsy';
$lang['%d user deleted'] = '%d käyttäjä poistettu';
$lang['%d hour'] = '%d tunti';
$lang['%d hours'] = '%d tuntia';
$lang['%d member'] = '%d jäsen';
$lang['%d members'] = '%d jäsentä';
$lang['Allow user customization'] = 'Salli kustomointi käyttäjille';
$lang['Allow users to edit their own comments'] = 'Salli käyttäjien muokata kommenttejaan';
$lang['Allow users to delete their own comments'] = 'Salli käyttäjien poistaa kommenttejaan';
$lang['Allow user registration'] = 'Salli käyttäjien rekisteröityminen';
$lang['All themes are up to date.'] = 'Kaikki teemat ovat ajan tasalla.';
$lang['%d parameters were updated.'] = '%d parametriä päivitetty.';
$lang['%d parameter was updated.'] = '%d parametri päivitetty.';
$lang['%d mails were sent.'] = '%d sähköpostiviestiä lähetetty.';
$lang['%d mail was sent.'] = '%d sähköpostiviesti lähetetty.';
$lang['%d mail was not sent.'] = '%d sähköpostiviesti lähettämättä.';
$lang['%d mails were not sent.'] = '%d sähköpostiviestiä lähettämättä.';
$lang['%d albums including'] = '%d albumia sisältäen';
$lang['%d album including'] = '%d albumi sisältäen';
$lang['Choose an action'] = 'Valitse toiminto';
$lang['%d user was updated.'] = '%d käyttäjä päivitetty.';
$lang['%d users were not updated.'] = '%d käyttäjää ei päivitetty.';
$lang['%d users were updated.'] = '%d käyttäjää päivitetty.';
$lang['%d album moved'] = '%d albumi siirretty';
$lang['Level 0'] = '---';
$lang['Level 4'] = 'Perhe';
$lang['Level 2'] = 'Kaverit';
$lang['Level 1'] = 'Kontaktit';
$lang['Main Page'] = 'Pääsivu';
$lang['IP'] = 'IP';
$lang['I decide to update anyway'] = 'Haluan päivittää silti';
$lang['Form'] = 'Lomake';
$lang['Groups'] = 'Ryhmät';
$lang['Groups and users'] = 'Ryhmät ja käyttäjät';
$lang['Guest Settings'] = 'Vieraiden asetukset';
$lang['Guest cannot be deleted'] = 'Vierasta ei voi poistaa';
$lang['Guests'] = 'Vieraat';
$lang['Height'] = 'Korkeus';
$lang['Hello'] = 'Hei';
$lang['Hello,'] = 'Hei,';
$lang['Group name'] = 'Ryhmän nimi';
$lang['Group management'] = 'Ryhmien hallinta';
$lang['Group'] = 'Ryhmä';
$lang['Go to'] = 'Siirry';
$lang['General statistics'] = 'Yleiset tilastot';
$lang['Deleted on'] = 'Poistettu';
$lang['Correction applied with success'] = 'Korjaus onnistuneesti lisätty';
$lang['Correction'] = 'Korjaus';
$lang['Check integrity'] = 'Eheyden tarkistus';
$lang['Check all'] = 'Valitse kaikki';
$lang['%s has been successfully updated.'] = '%s päivitettiin onnistuneesti.';
$lang['%d waiting for validation'] = '%d odottaa hyväksyntää';
$lang['%d user was not updated.'] = '%d käyttäjää ei päivitetty';
$lang[' and %d virtuals'] = 'ja %d virtuaalista';
$lang[' and %d virtual'] = 'ja %d virtuaalinen';
$lang['Rename'] = 'Nimeä uudelleen';
$lang['Please wait...'] = 'Odota, ole hyvä...';
$lang['Piwigo version'] = 'Piwigon versio';
$lang['Overall'] = 'Yleiskatsaus';
$lang['Minimum height'] = 'Vähimmäiskorkeus';
$lang['Locked'] = 'Lukittu';
$lang['Lock gallery'] = 'Lukitse galleria';
$lang['Lock albums'] = 'Lukitse albumit';
$lang['Installed Themes'] = 'Asennetut teemat';
$lang['Installed Languages'] = 'Asennetut kielet';
$lang['Help Me'] = 'Apua';
$lang['Duplicates'] = 'Kaksoiskappaleet';
$lang['Duplicate'] = 'Kahdenna';
$lang['Delete selected users'] = 'Poista valitut käyttäjät';
$lang['Delete this language'] = 'Poista tämä kieli';
$lang['Delete Representant'] = 'Poista albumin esikatselukuva';
$lang['%d anomalies have been detected corrected.'] = '%d epäkohtaa löydetty ja korjattu.';
$lang['%d anomalies have been detected.'] = '%d epäkohtaa havaittu.';
$lang['%d anomalies have been ignored.'] = '%d epäkohtaa ohitettu.';
$lang['%d anomalies have not been corrected.'] = '%d epäkohtaa ei ole korjattu.';
$lang['%d anomaly has been corrected.'] = '%d epäkohtaa korjattiin.';
$lang['%d anomaly has been detected.'] = '%d epäkohtaa havaittiin.';
$lang['%d anomaly has been ignored.'] = '%d epäkohtaa ohitettiin.';
$lang['%d anomaly has not been corrected.'] = '%d ei olla korjattu.';
$lang['%d association'] = '%d assosiaatiota';
$lang['%d associations'] = '%d assosiaatiota';
$lang['%d line filtered'] = '%d rivi rajattu';
$lang['%d lines filtered'] = '%d riviä rajattu';
$lang['%d of %d photos selected'] = '%d/%d kuvaa valittu';
$lang['%d physical'] = '%d fyysistä';
$lang['%d physicals'] = '%d fyysistä';
$lang['%d tag'] = '%d tunniste';
$lang['%d tags'] = '%d tunnistetta';
$lang['%d user comment rejected'] = '%d kommentti hylätty';
$lang['%d user comment validated'] = '%d kommentti hyväksytty';
$lang['%d user comments rejected'] = '%d kommenttia hylätty';
$lang['New tag'] = 'Uusi tägi';
$lang['Number of comments per page'] = 'Kommenttien lukumäärä sivua kohden';
$lang['Move albums'] = 'Siirrä albumeja';
$lang['Move to album'] = 'Siirrä albumiin';
$lang['Manage Permissions'] = 'Hallitse oikeuksia';
$lang['Hide'] = 'Piilota';
$lang['Gallery title'] = 'Gallerian otsikko';
$lang['Default photos order'] = 'Kuvien oletusjärjestys';
$lang['Default user cannot be deleted'] = 'Oletuskäyttäjää ei voi poistaa';
$lang['Delete orphan tags'] = 'Poista käyttämättömät tägit';
$lang['Delete selected photos'] = 'Poista valitut kuvat';
$lang['Delete selected tags'] = 'Poista valitut tägit';
$lang['Delete this theme'] = 'Poista tämä teema';
$lang['Add a criteria'] = 'Lisää kriteeri';
$lang['Add a filter'] = 'Lisää filtteri';
$lang['Add a tag'] = 'Lisää tägi';
$lang['Add a virtual album'] = 'Lisää virtuaalinen albumi';
$lang['Add group'] = 'Lisää ryhmä';
$lang['Add tags'] = 'Lisää tägejä';
$lang['Added by %s'] = 'Lisännyt %s';
$lang['Album "%s" has been added'] = 'Albumi "%s" lisätty';
$lang['Album "%s" now contains %d photos'] = 'Albumi "%s" sisältää nyt %d kuvaa';
$lang['Albums automatically sorted'] = 'Albumit järjestetty automaattisesti';
$lang['All %d photos are selected'] = 'Kaikki %d kuvaa ovat valittuina';
$lang['All extensions are up to date.'] = 'Kaikki laajennukset ovat ajan tasalla.';
$lang['ACCESS_5'] = 'Ei pääsyä';
$lang['Action'] = 'Toiminto';
$lang['Actions'] = 'Toiminnot';
$lang['Select an album'] = 'Valitse albumi';
$lang['Select at least one album'] = 'Valitse vähintään yksi albumi';
$lang['Select at least one comment'] = 'Valitse vähintään yksi kommentti';
$lang['Select at least one photo'] = 'Valitse vähintään yksi kuva';
$lang['Select at least one user'] = 'Valitse vähintään yksi käyttäjä';
$lang['Select groups...'] = 'Valitse ryhmät...';
$lang['Select users...'] = 'Valitse käyttäjät...';
$lang['Two updates are available'] = 'Kaksi päivitystä on saatavilla';
$lang['Thumbnails generation in progress...'] = 'Luodaan pienoiskuvia...';
$lang['Virtual album added'] = 'Virtuaalinen albumi lisätty';
$lang['Virtual album deleted'] = 'Virtuaalinen albumi poistettu';
$lang['You are running the latest version of Piwigo.'] = 'Sinulla on uusin versio Piwigosta.';
$lang['You cannot delete your account'] = 'Et voi poistaa omaa käyttäjätiliäsi';
$lang['You cannot move an album in its own sub album'] = 'Et voi siirtää albumia omaan ala-albumiinsa';
$lang['an error happened'] = 'tapahtui virhe';
$lang['any visitor can see this album'] = 'kuka tahansa vierailija näkee tämän albumin';
$lang['automatic order'] = 'automaattinen järjestys';
$lang['default values'] = 'oletusarvot';
$lang['unknown'] = 'tuntematon';
$lang['user_status_admin'] = 'Ylläpitäjä';
$lang['user_status_guest'] = 'Vieras';
$lang['user_status_normal'] = 'Käyttäjä';
?>
